@@ -31,62 +31,22 @@ from .prefix_scan import prefix_scan
 ffi_new = ffi.new
 
 
-@njit
-def _head_indices_vector_bitmap(bitmap, values, size, dtype, n, is_iso):  # pragma: no cover
-    indices = np.empty(n, dtype=np.uint64)
-    if is_iso:
-        vals = np.empty(1, dtype=dtype)
-        vals[0] = values[0]
-    else:
-        vals = np.empty(n, dtype=dtype)
-    j = 0
-    for i in range(size):
-        if bitmap[i]:
-            indices[j] = i
-            if not is_iso:
-                vals[j] = values[i]
-            j += 1
-            if j == n:
-                break
-    return indices, vals
-
-
 def head(vector, n=10, dtype=None, *, sort=False):
-    """Like ``vector.to_values()``, but only returns the first n elements.
+    """Like ``vector.to_coo()``, but only returns the first n elements.
 
     If sort is True, then the results will be sorted by index, otherwise the order of the
     result is not guaranteed.  Formats full and bitmap should always return in sorted order.
-
-    This changes ``vector.gb_obj``, so care should be taken when using multiple threads.
     """
+    if vector._nvals <= n:
+        return vector.to_coo(dtype, sort=sort)
+    if sort:
+        vector.wait()
     if dtype is None:
         dtype = vector.dtype
     else:
         dtype = lookup_dtype(dtype)
-    n = min(n, vector._nvals)
-    if n == 0:
-        return (np.empty(0, dtype=np.uint64), np.empty(0, dtype=dtype.np_type))
-    is_iso = vector.ss.is_iso
-    d = vector.ss.unpack(raw=True, sort=sort)
-    fmt = d["format"]
-    try:
-        if fmt == "full":
-            indices = np.arange(n, dtype=np.uint64)
-            vals = d["values"][:n].astype(dtype.np_type)
-        elif fmt == "bitmap":
-            indices, vals = _head_indices_vector_bitmap(
-                d["bitmap"], d["values"], d["size"], dtype.np_type, n, is_iso
-            )
-        elif fmt == "sparse":
-            indices = d["indices"][:n].copy()
-            vals = d["values"][:n].astype(dtype.np_type)
-        else:  # pragma: no cover
-            raise RuntimeError(f"Invalid format: {fmt}")
-    finally:
-        vector.ss.pack_any(take_ownership=True, **d)
-    if is_iso:
-        vals = np.broadcast_to(vals[:1], (n,))
-    return indices, vals
+    indices, vals = zip(*itertools.islice(vector.ss.iteritems(), n))
+    return np.array(indices, np.uint64), np.array(vals, dtype.np_type)
 
 
 class VectorConfig(BaseConfig):
@@ -182,7 +142,7 @@ class ss:
             format = "bitmap"
         elif sparsity_status == lib.GxB_FULL:
             format = "full"
-        else:  # pragma: no cover
+        else:  # pragma: no cover (sanity)
             raise NotImplementedError(f"Unknown sparsity status: {sparsity_status}")
         return format
 
@@ -194,7 +154,7 @@ class ss:
 
         """
         warnings.warn(
-            "`Matrix.ss.diag` is deprecated; "
+            "`Vector.ss.diag` is deprecated; "
             "please use `Matrix.diag` or `Vector.ss.build_diag` instead",
             DeprecationWarning,
         )
@@ -328,7 +288,7 @@ class ss:
         See Also
         --------
         Vector.build
-        Vector.from_values
+        Vector.from_coo
         """
         indices = ints_to_numpy_buffer(indices, np.uint64, name="indices")
         scalar = _as_scalar(value, self._parent.dtype, is_cscalar=False)  # pragma: is_grbscalar
@@ -348,7 +308,7 @@ class ss:
         it = it_ptr[0]
         success = lib.GrB_SUCCESS
         info = lib.GxB_Vector_Iterator_attach(it, self._parent._carg, NULL)
-        if info != success:  # pragma: no cover
+        if info != success:  # pragma: no cover (safety)
             lib.GxB_Iterator_free(it_ptr)
             raise _error_code_lookup[info]("Vector iterator failed to attach")
         if seek < 0:
@@ -391,7 +351,7 @@ class ss:
         except GeneratorExit:
             pass
         else:
-            if info != lib.GxB_EXHAUSTED:  # pragma: no cover
+            if info != lib.GxB_EXHAUSTED:  # pragma: no cover (safety)
                 raise _error_code_lookup[info]("Vector iterator failed")
         finally:
             lib.GxB_Iterator_free(it_ptr)
@@ -425,7 +385,7 @@ class ss:
         except GeneratorExit:
             pass
         else:
-            if info != lib.GxB_EXHAUSTED:  # pragma: no cover
+            if info != lib.GxB_EXHAUSTED:  # pragma: no cover (safety)
                 raise _error_code_lookup[info]("Vector iterator failed")
         finally:
             lib.GxB_Iterator_free(it_ptr)
@@ -460,7 +420,7 @@ class ss:
         except GeneratorExit:
             pass
         else:
-            if info != lib.GxB_EXHAUSTED:  # pragma: no cover
+            if info != lib.GxB_EXHAUSTED:  # pragma: no cover (safety)
                 raise _error_code_lookup[info]("Vector iterator failed")
         finally:
             lib.GxB_Iterator_free(it_ptr)
@@ -495,7 +455,7 @@ class ss:
 
         See Also
         --------
-        Vector.to_values
+        Vector.to_coo
         Vector.ss.import_any
 
         Return values
@@ -593,13 +553,13 @@ class ss:
             indices = claim_buffer(ffi, vi[0], vi_size[0] // index_dtype.itemsize, index_dtype)
             values = claim_buffer(ffi, vx[0], vx_size[0] // dtype.itemsize, dtype)
             if not raw:
-                if indices.size > nvals:  # pragma: no cover
+                if indices.size > nvals:
                     indices = indices[:nvals]
                 if is_iso:
-                    if values.size > 1:  # pragma: no cover
+                    if values.size > 1:  # pragma: no cover (suitesparse)
                         values = values[:1]
                 else:
-                    if values.size > nvals:  # pragma: no cover
+                    if values.size > nvals:
                         values = values[:nvals]
             rv = {
                 "size": size,
@@ -623,13 +583,13 @@ class ss:
             bitmap = claim_buffer(ffi, vb[0], vb_size[0] // bool_dtype.itemsize, bool_dtype)
             values = claim_buffer(ffi, vx[0], vx_size[0] // dtype.itemsize, dtype)
             if not raw:
-                if bitmap.size > size:  # pragma: no cover
+                if bitmap.size > size:  # pragma: no branch (suitesparse)
                     bitmap = bitmap[:size]
                 if is_iso:
-                    if values.size > 1:  # pragma: no cover
+                    if values.size > 1:  # pragma: no cover (suitesparse)
                         values = values[:1]
                 else:
-                    if values.size > size:  # pragma: no cover
+                    if values.size > size:  # pragma: no branch (suitesparse)
                         values = values[:size]
             rv = {
                 "bitmap": bitmap,
@@ -646,10 +606,10 @@ class ss:
             values = claim_buffer(ffi, vx[0], vx_size[0] // dtype.itemsize, dtype)
             if not raw:
                 if is_iso:
-                    if values.size > 1:  # pragma: no cover
+                    if values.size > 1:
                         values = values[:1]
                 else:
-                    if values.size > size:  # pragma: no cover
+                    if values.size > size:  # pragma: no branch (suitesparse)
                         values = values[:size]
             rv = {}
             if raw or is_iso:
@@ -700,7 +660,7 @@ class ss:
 
         See Also
         --------
-        Vector.from_values
+        Vector.from_coo
         Vector.ss.export
         Vector.ss.import_sparse
         Vector.ss.import_bitmap
@@ -824,7 +784,7 @@ class ss:
                 dtype=dtype,
                 name=name,
             )
-        elif format == "bitmap":
+        if format == "bitmap":
             return getattr(obj, f"{method}_bitmap")(
                 nvals=nvals,
                 bitmap=bitmap,
@@ -835,7 +795,7 @@ class ss:
                 dtype=dtype,
                 name=name,
             )
-        elif format == "full":
+        if format == "full":
             return getattr(obj, f"{method}_full")(
                 values=values,
                 size=size,
@@ -844,8 +804,7 @@ class ss:
                 dtype=dtype,
                 name=name,
             )
-        else:
-            raise ValueError(f"Invalid format: {format}")
+        raise ValueError(f"Invalid format: {format}")
 
     @classmethod
     def import_sparse(
@@ -1459,8 +1418,7 @@ class ss:
         if size is None and self._parent._nvals == 0 or size == 0:
             if asindex:
                 return gb.Vector(UINT64, size=0, name=name)
-            else:
-                return gb.Vector(self._parent.dtype, size=0, name=name)
+            return gb.Vector(self._parent.dtype, size=0, name=name)
         do_sort = how in {"first", "last"}
         info = self._parent.ss.export("sparse", sort=do_sort)
         if size is None:
@@ -1635,7 +1593,7 @@ class ss:
 
 
 @njit
-def random_choice(n, k):  # pragma: no cover
+def random_choice(n, k):  # pragma: no cover (numba)
     if k >= n:
         return np.arange(n, dtype=np.uint64)
     choices = np.empty(k, dtype=np.uint64)
