@@ -5,6 +5,7 @@ import numpy as _np
 from numpy import find_common_type as _find_common_type
 from numpy import promote_types as _promote_types
 
+from . import backend
 from .core import NULL as _NULL
 from .core import ffi as _ffi
 from .core import lib as _lib
@@ -107,34 +108,34 @@ def register_anonymous(dtype, name=None):
                 raise ValueError("dtype must not be a builtin type")
             rv.name = name  # Rename an existing object (a little weird, but okay)
         return rv
-    elif dtype.hasobject:
+    if dtype.hasobject:
         raise ValueError("dtype must not allow Python objects")
-    else:
-        from .exceptions import check_status_carg
 
-        gb_obj = _ffi.new("GrB_Type*")
-        if hasattr(_lib, "GxB_MAX_NAME_LEN"):
-            # SS, SuiteSparse-specific: naming dtypes
-            # We name this so that we can serialize and deserialize UDTs
-            # We don't yet have C definitions
-            np_repr = _dtype_to_string(dtype).encode()
-            if len(np_repr) > _lib.GxB_MAX_NAME_LEN:
-                msg = (
-                    f"UDT repr is too large to serialize ({len(repr(dtype).encode())} > "
-                    f"{_lib.GxB_MAX_NAME_LEN})."
-                )
-                if name is not None:
-                    np_repr = name.encode()[: _lib.GxB_MAX_NAME_LEN]
-                else:
-                    np_repr = np_repr[: _lib.GxB_MAX_NAME_LEN]
-                _warnings.warn(
-                    f"{msg}.  It will use the following name, "
-                    f"and the dtype may need to be specified when deserializing: {np_repr}"
-                )
-            status = _lib.GxB_Type_new(gb_obj, dtype.itemsize, np_repr, _NULL)
-        else:  # pragma: no cover
-            status = _lib.GrB_Type_new(gb_obj, dtype.itemsize)
-        check_status_carg(status, "Type", gb_obj[0])
+    from .exceptions import check_status_carg
+
+    gb_obj = _ffi.new("GrB_Type*")
+    if backend == "suitesparse":
+        # We name this so that we can serialize and deserialize UDTs
+        # We don't yet have C definitions
+        np_repr = _dtype_to_string(dtype).encode()
+        if len(np_repr) > _lib.GxB_MAX_NAME_LEN:
+            msg = (
+                f"UDT repr is too large to serialize ({len(repr(dtype).encode())} > "
+                f"{_lib.GxB_MAX_NAME_LEN})."
+            )
+            if name is not None:
+                np_repr = name.encode()[: _lib.GxB_MAX_NAME_LEN]
+            else:
+                np_repr = np_repr[: _lib.GxB_MAX_NAME_LEN]
+            _warnings.warn(
+                f"{msg}.  It will use the following name, "
+                f"and the dtype may need to be specified when deserializing: {np_repr}"
+            )
+        status = _lib.GxB_Type_new(gb_obj, dtype.itemsize, np_repr, _NULL)
+    else:
+        status = _lib.GrB_Type_new(gb_obj, dtype.itemsize)
+    check_status_carg(status, "Type", gb_obj[0])
+
     # For now, let's use "opaque" unsigned bytes for the c type.
     if name is None:
         name = _default_name(dtype)
@@ -173,7 +174,7 @@ if _supports_complex and hasattr(_lib, "GxB_FC32"):
     FC32 = DataType(
         "FC32", _lib.GxB_FC32, "GxB_FC32", "float _Complex", _numba.types.complex64, _np.complex64
     )
-if _supports_complex and hasattr(_lib, "GrB_FC32"):  # pragma: no coverage
+if _supports_complex and hasattr(_lib, "GrB_FC32"):  # pragma: no coverage (invalid)
     FC32 = DataType(
         "FC32", _lib.GrB_FC32, "GrB_FC32", "float _Complex", _numba.types.complex64, _np.complex64
     )
@@ -186,7 +187,7 @@ if _supports_complex and hasattr(_lib, "GxB_FC64"):
         _numba.types.complex128,
         _np.complex128,
     )
-if _supports_complex and hasattr(_lib, "GrB_FC64"):  # pragma: no coverage
+if _supports_complex and hasattr(_lib, "GrB_FC64"):  # pragma: no coverage (invalid)
     FC64 = DataType(
         "FC64",
         _lib.GrB_FC64,
@@ -325,13 +326,12 @@ def _default_name(dtype):
         subdtype = _default_name(dtype.subdtype[0])
         shape = ", ".join(map(str, dtype.subdtype[1]))
         return f"{subdtype}[{shape}]"
-    elif dtype.names:
+    if dtype.names:
         args = ", ".join(
             f"{name!r}: {_default_name(dtype.fields[name][0])}" for name in dtype.names
         )
         return "{%s}" % args
-    else:
-        return repr(dtype)
+    return repr(dtype)
 
 
 def _dtype_to_string(dtype):
@@ -353,13 +353,13 @@ def _dtype_to_string(dtype):
         np_type = dtype.np_type
     s = str(np_type)
     try:
-        if _np.dtype(_np.lib.format.safe_eval(s)) == np_type:
+        if _np.dtype(_np.lib.format.safe_eval(s)) == np_type:  # pragma: no branch (safety)
             return s
     except Exception:
         pass
     if _np.dtype(np_type.str) == np_type:
         return repr(np_type.str)
-    else:  # pragma: no cover
+    else:  # pragma: no cover (safety)
         raise ValueError(f"Unable to reliably convert dtype to string and back: {dtype}")
 
 
