@@ -8,12 +8,14 @@ import numpy as np
 import pytest
 
 import graphblas as gb
-from graphblas import binary, dtypes, replace
+from graphblas import backend, binary, dtypes, replace
 
 from .conftest import autocompute, compute
 
 from graphblas import Matrix, Scalar, Vector  # isort:skip (for dask-graphblas)
 
+suitesparse = backend == "suitesparse"
+
 
 @pytest.fixture
 def s():
@@ -314,7 +316,7 @@ def test_wait(s):
 
 @autocompute
 def test_expr_is_like_scalar(s):
-    v = Vector.from_values([1], [2])
+    v = Vector.from_coo([1], [2])
     attrs = {attr for attr, val in inspect.getmembers(s)}
     expr_attrs = {attr for attr, val in inspect.getmembers(v.inner(v))}
     infix_attrs = {attr for attr, val in inspect.getmembers(v @ v)}
@@ -349,7 +351,7 @@ def test_expr_is_like_scalar(s):
 
 @autocompute
 def test_index_expr_is_like_scalar(s):
-    v = Vector.from_values([1], [2])
+    v = Vector.from_coo([1], [2])
     attrs = {attr for attr, val in inspect.getmembers(s)}
     expr_attrs = {attr for attr, val in inspect.getmembers(v[0])}
     # Should we make any of these raise informative errors?
@@ -379,7 +381,7 @@ def test_index_expr_is_like_scalar(s):
 
 def test_ndim(s):
     assert s.ndim == 0
-    v = Vector.from_values([1], [2])
+    v = Vector.from_coo([1], [2])
     assert v.inner(v).ndim == 0
     assert (v @ v).ndim == 0
 
@@ -420,7 +422,7 @@ def test_scalar_complex(dtype):
 
 @autocompute
 def test_scalar_expr(s):
-    v = Vector.from_values([1], [2])
+    v = Vector.from_coo([1], [2])
     expr = v.inner(v)
     t = expr._new_scalar(s.dtype)
     assert t.is_cscalar is s.is_cscalar
@@ -438,19 +440,24 @@ def test_scalar_expr(s):
 
 
 def test_sizeof(s):
-    assert 1 < sys.getsizeof(s) < 1000
+    if suitesparse or s._is_cscalar:
+        assert 1 < sys.getsizeof(s) < 1000
+    else:
+        with pytest.raises(TypeError):
+            sys.getsizeof(s)
 
 
-def test_concat(s):
+@pytest.mark.skipif("not suitesparse")
+def test_ss_concat(s):
     empty = Scalar(int)
     v = gb.ss.concat([s, s, empty])
-    expected = Vector.from_values([0, 1], 5, size=3)
+    expected = Vector.from_coo([0, 1], 5, size=3)
     assert v.isequal(expected)
     A = gb.ss.concat([[s, s, empty]])
-    expected = Matrix.from_values([0, 0], [0, 1], 5, nrows=1, ncols=3)
+    expected = Matrix.from_coo([0, 0], [0, 1], 5, nrows=1, ncols=3)
     assert A.isequal(expected)
     A = gb.ss.concat([[s], [s], [empty]])
-    expected = Matrix.from_values([0, 1], [0, 0], 5, nrows=3, ncols=1)
+    expected = Matrix.from_coo([0, 1], [0, 0], 5, nrows=3, ncols=1)
     assert A.isequal(expected)
 
 
